#!/usr/bin/php
<?php
/*
 SPDX-FileCopyrightText: © 2012 Hewlett-Packard Development Company, L.P.

 SPDX-License-Identifier: GPL-2.0-only
*/
/**
 * \file vmcheck.php
 * \brief make sure the vm's for package testing are on and have a snapshot
 *
 * @version "$Id$"
 * Created on March 15, 2012 by Mark Donohoe
 */

require_once('../lib/common-vm.php');

$vmServers = array(
//    'foss-vmhost1.usa.hp.com',
//    'foss-vmhost2.usa.hp.com',
//    'foss-vmhost3.usa.hp.com',
//    'foss-vmhost4.usa.hp.com',
    'haymitch.fc.hp.com',
    'primrose.fc.hp.com',
    'madge.fc.hp.com',
    'buttercup.fc.hp.com'
);

// vmware does not change the name of the initial vm, it just displays the new
// name.
/*
$pkgVms = array(
    'squeze32',
    'squeze64',
    'fed15-32',
    'fed15-64',
    'rhel6-232',
    'rhel6-264_1',
    'u10-043-32_1',
    'u10-043-64',
    'ubun11-0432',
    'ubun11.04.64',
    'u1110-32',
    'u1110-64',
);
*/
$pkgVms = array(
    'fo-debian-squeeze32.fc.hp.com',
    'fo-debian-squeeze64.fc.hp.com',
    'fo-debian-wheezy32.fc.hp.com',
    'fo-debian-wheezy64.fc.hp.com',
    'fo-centos-6-32.fc.hp.com',
    'fo-centos-6-64.fc.hp.com',
    'fo-fedora-19-32.fc.hp.com',
    'fo-fedora-19-64.fc.hp.com',
    'fo-fedora-18-32.fc.hp.com',
    'fo-fedora-18-64.fc.hp.com',
    'fo-ubuntu-1204-32.fc.hp.com',
    'fo-ubuntu-1204-64.fc.hp.com',
    'fo-ubuntu-1210-32.fc.hp.com',
    'fo-ubuntu-1210-64.fc.hp.com',
    'fo-ubuntu-1304-32.fc.hp.com',
    'fo-ubuntu-1304-64.fc.hp.com',
    'fo-ubuntu-1310-32.fc.hp.com',
    'fo-ubuntu-1310-64.fc.hp.com',
    'fo-fedora-20-32.fc.hp.com',
    'fo-fedora-20-64.fc.hp.com',
    'fo-ubuntu-1404-32.fc.hp.com',
    'fo-ubuntu-1404-64.fc.hp.com',
);


$hosts = array();
$listOut = array();
$vmList = array();

// gather vm's on each server
// determine what server each vm is on, build an array with [vmhost][vmname]

foreach($vmServers as $host)
{
  $host = trim($host);
  $cmd = "vmware-cmd -H $host -U root -P iforgot -l";
  $last = exec($cmd, $listOut, $rtn);
  foreach($listOut as $vmMachine)
  {
    if(empty($vmMachine))
    {
      continue;
    }
    $parts = explode('/', $vmMachine);
    if(in_array(trim($parts[4]), $pkgVms))
    {
      //echo "DB: matched! {$parts[4]}\n";
      $vmList[] = $vmMachine;
    }
    $hosts[$host] = $vmList;
  } // foreach
  $vmList = array();
  $listOut = array();
} // foreach

/*
 * For each machine, turn it on, make sure there is a snapshot record machines
 * that are ready to test in an array.  Write the array to a vm.ini file.  This
 * file will be used by vmrevert to revert the vms to the current snapshot.
 *
 */
$machinesReady = array();
foreach($hosts as $host => $vms)
{
  if(empty($vms))
  {
    echo "Note: no vm's for host $host\n";
    continue;
  }
  foreach($vms as $vm)
  {
    if(!vmOps($host, $vm, 'getstate'))
    {
      echo "Warning: $vm would not start, not in this test run.\n";
      continue;
    }
    if(!vmOps($host, $vm, 'hassnapshot'))
    {
      echo "Warning: $vm does not have a snapshot!\n";

    }
    $machinesReady[$host][] = $vm;
  }
}
//echo "DB: the machines that will be used to test are:\n";
//print_r($machinesReady) . "\n";

// create ini file, use vmname=vm for entries.

$dataFile = 'vm.ini';
$VM = fopen($dataFile, 'w') or die("FATAL! Cannot open $dataFile\n");
$message = "; This file was generated by vmcheck.php on:" .
  date("D M j G:i:s T Y") . "\n\n";
fwrite($VM, $message);
foreach ($machinesReady as $host => $vms)
{
  if(!fwrite($VM, '[' . $host . "]\n"))
  {
    echo "FATAL! could not write to $dataFile\n";
    exit(1);
  }
  foreach ($vms as $vm)
  {
    $vmParts = explode('/', $vm);
    if(!fwrite($VM, $vmParts[4] . '=' . "$vm\n"))
    {
      echo "FATAL! could not write to $dataFile\n";
      exit(1);
    }
  }

}
exit(0);
?>
