<?php
/*
 SPDX-FileCopyrightText: © 2020 Siemens AG
 Author: Gaurav Mishra <mishra.gaurav@siemens.com>

 SPDX-License-Identifier: GPL-2.0-only
*/
/**
 * @file
 * @brief Tests for Reueser model
 */

namespace Fossology\UI\Api\Test\Models;

use Fossology\UI\Api\Models\Reuser;

/**
 * @class ReuserTest
 * @brief Tests for Reuser model
 */
class ReuserTest extends \PHPUnit\Framework\TestCase
{
  /**
   * @test
   * -# Test constructor and Reuser::getArray()
   */
  public function testReuserConst()
  {
    $expectedArray = [
      "reuse_upload"   => 2,
      "reuse_group"    => 'fossy',
      "reuse_main"     => true,
      "reuse_enhanced" => false,
      "reuse_copyright" => false,
      "reuse_report"   => false
    ];

    $actualReuser = new Reuser(2, 'fossy', true);

    $this->assertEquals($expectedArray, $actualReuser->getArray());
  }

  /**
   * @test
   * -# Test if UnexpectedValueException is thrown for invalid upload and group
   *    id by constructor
   */
  public function testReuserException()
  {
    $this->expectException(\UnexpectedValueException::class);
    $this->expectExceptionMessage("reuse_upload should be integer");
    $object = new Reuser('alpha', 2);
  }

  /**
   * @test
   * -# Test for Reuser::setUsingArray()
   */
  public function testSetUsingArray()
  {
    $expectedArray = [
      "reuse_upload"   => 2,
      "reuse_group"    => 'fossy',
      "reuse_main"     => 'true',
      "reuse_enhanced" => false,
      "reuse_copyright" => false,
      "reuse_report"   => false
    ];

    $actualReuser = new Reuser(1, 'fossy');
    $actualReuser->setUsingArray($expectedArray);

    $expectedArray["reuse_main"] = true;
    $this->assertEquals($expectedArray, $actualReuser->getArray());
  }

  /**
   * @test
   * -# Test for Reuser::setUsingArray()
   * -# Add some changes to the array.
   */
  public function testSetUsingArraySomeOptions()
  {
    $expectedArray = [
      "reuse_upload"   => 2,
      "reuse_group"    => 'fossy',
      "reuse_main"     => 'true',
      "reuse_enhanced" => false,
      "reuse_copyright" => 'true',
      "reuse_report"   => false
    ];

    $actualReuser = new Reuser(1, 'fossy');
    $actualReuser->setUsingArray($expectedArray);

    $expectedArray["reuse_main"] = true;
    $expectedArray["reuse_copyright"] = true;
    $this->assertEquals($expectedArray, $actualReuser->getArray());
  }

  /**
   * @test
   * -# Test if UnexpectedValueException is thrown for invalid upload and group
   *    id by Reuser::setUsingArray()
   */
  public function testSetUsingArrayException()
  {
    $expectedArray = [
      "reuse_upload"   => 'alpha',
      "reuse_group"    => 'fossy',
      "reuse_main"     => 'true',
      "reuse_enhanced" => false
    ];

    $this->expectException(\UnexpectedValueException::class);
    $this->expectExceptionMessage("Reuse upload should be an integer");

    $actualReuser = new Reuser(1, 'fossy');
    $actualReuser->setUsingArray($expectedArray);
  }
}
